(function ($, Drupal, drupalSettings) {
  Drupal.behaviors.countdownTimer = {
    attach: function (context, settings) {
      const endDateField = $('input[name="end_date"]', context);
      let endTimestamp = drupalSettings.countdownClock.endTimestamp;

      function updateCountdown() {
        const now = Math.floor(Date.now() / 1000);
        const remainingTime = endTimestamp - now;

        if (remainingTime <= 0) {
          $('#countdown-timer').html('Countdown Finished!');
          clearInterval(interval);
          return;
        }

        const days = Math.floor(remainingTime / 86400);
        const hours = Math.floor((remainingTime % 86400) / 3600);
        const minutes = Math.floor((remainingTime % 3600) / 60);
        const seconds = remainingTime % 60;

        // Create a function to wrap each digit in a span
        function wrapDigits(value) {
          return String(value).padStart(2, '0').split('').map(digit => `<span>${digit}</span>`).join('');
        }

        $('#countdown-timer #days').html(wrapDigits(days));
        $('#countdown-timer #hours').html(wrapDigits(hours));
        $('#countdown-timer #minutes').html(wrapDigits(minutes));
        $('#countdown-timer #seconds').html(wrapDigits(seconds));
      }

      // Immediately update countdown and set interval
      updateCountdown();
      const interval = setInterval(updateCountdown, 1000);

      // Update the end timestamp if the end date changes
      endDateField.on('change', function () {
        const newDate = $(this).val();
        endTimestamp = new Date(newDate).getTime() / 1000;
      });
    }
  };
})(jQuery, Drupal, drupalSettings);
